{% extends "registration/base.html" %}{% load i18n %}
{% block registration_content %}
<h3>{% trans "Registration complete" %}</h3>
<p></p>
<p>
{% blocktrans %}
We sent you an email. It will help you to activate your account.
{% endblocktrans %}
</p>
{% endblock %}
