{% load i18n coop_edition %}

{% cms_edit article %}
    <h2 id="title">{{ article.title }}</h2>
    <div id="logo">{{ article.logo }}</div>
    <div id="content">{{ article.content }}</div>
{% end_cms_edit %}
