{% extends "registration/base.html" %}{% load i18n %}
{% block registration_content %}
<h3>{% trans "Votre demande de création de compte a été prise en compte!" %}</h3>
<p></p>
<p>{% trans "Vous pouvez à présent vous connecter" %}</p>
<p><a class="btn btn-primary" href="{% url 'login' %}">{% trans "Login" %}</a></p>

{% endblock %}