<div id="carousel" class="carousel slide" {{ carousel_extra_args }} data-ride="carousel">
    <!-- Indicators -->
    <ol class="carousel-indicators">
    {% for headline in headlines %}
      <li data-target="#carousel" data-slide-to="{{forloop.counter0}}" class="{% if forloop.counter0 == 0 %}active{% endif %}"></li>
    {% endfor %}
    </ol>

    <!-- Wrapper for slides -->
    <div class="carousel-inner">
    {% for headline in headlines %}
      <div class="item {% if forloop.counter0 == 0 %}active{% endif %}">
        <img src="{{headline.get_headline_image}}" alt="{{headline.title}}">
        <div class="carousel-caption">
          <h3 class="carousel-caption-title"><a href="{{ headline.get_absolute_url }}">{{ headline.title }}</a></h3>
          <div class="carousel-caption-summary">
          {{ headline.summary }}
          </div>
        </div>
      </div>
    {% endfor %}
    </div>

    <!-- Controls -->
    <a class="left carousel-control" href="#carousel" role="button" data-slide="prev">
      <span class="glyphicon glyphicon-chevron-left"></span>
    </a>
    <a class="right carousel-control" href="#carousel" role="button" data-slide="next">
      <span class="glyphicon glyphicon-chevron-right"></span>
    </a>
</div>