#pageslide-content {
	height: 100%;
}

body {
    color: #000;
}
a {
    color: #000;
}

.library {
	margin: auto;
	height: 100%;
	border-right: solid thin #777;
	font: 12px Tahoma, Arial,"Trebuchet MS", Trebuchet;
	-webkit-box-shadow: #666 0px 2px 8px;
	-moz-box-shadow: #666 0px 2px 8px;
	box-shadow: #555 0px 2px 8px;
	background: #FFFFFF;
	background: -webkit-gradient(linear, 0 0, 0 bottom, from(#BBB), to(#FFFFFF));
	background: -webkit-linear-gradient(#BBB, #FFFFFF);
	background: -moz-linear-gradient(#BBB, #FFF);
	background: -ms-linear-gradient(#BBB, #FFF);
	background: -o-linear-gradient(#BBB, #FFF);
	background: linear-gradient(#BBB, #FFF);
}

.media-selector {
	height: 40px;
	background: #FFFFFF;
	background: -webkit-gradient(linear, 0 0, 0 bottom, from(#FFFFFF), to(#ABABAB));
	background: -webkit-linear-gradient(#FFFFFF, #ABABAB);
	background: -moz-linear-gradient(#FFFFFF, #ABABAB);
	background: -ms-linear-gradient(#FFFFFF, #ABABAB);
	background: -o-linear-gradient(#FFFFFF, #ABABAB);
	background: linear-gradient(#FFFFFF, #ABABAB);
	font-weight: bold;
	font-size: 14px;
	line-height: 40px;
}

.media-selector a {
	height: 40px;
	display: inline-block;
	padding-left: 10px;
	padding-right: 10px;
	color: #949494;
}

.media-selector a.active {
	text-decoration: none;
	background-color: rgba(255,255,255,0.45);
	color: #2a62d5;
}

.media-filters {
	background: #FFFFFF;
	background: linear-gradient(#FFFFFF, #ABABAB);
	font-weight: bold;
	line-height: 20px;
	padding-left: 8px;
}

.media-filters a {
	height: 20px;
	display: inline-block;
	padding: 2px;
	color: #949494;
}

.media-filters a.active {
	color: #000;
}


.close-slider a {
	float: right;
	background: transparent url("/static/img/cross.png") no-repeat 6px 7px;
	width: 28px;
	margin-right: 6px;
	margin-top: 5px;
	border: 1px inset #cecfd0;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	border-radius: 6px;
	height: 28px;
}

.library h3 {
	color: #000;
}

.library .pagination .page, .library .pagination .prev, .library .pagination .next {
	padding: 0 1px 0 1px;
}

.library-images {
	padding: 10px;
}

.library-image {
	display: inline-block;
	text-align: center;
	max-width: 80px;
	overflow: hidden;
	margin: 0 10px;
	vertical-align: top;
}

.library-images img.library-thumbnail {
	border: 6px solid white;
	-webkit-box-shadow: #666 0px 2px 8px;
	-moz-box-shadow: #666 0px 2px 8px;
	box-shadow: #555 0px 2px 8px;
	/*margin: 12px; */
	cursor: move;
	width: 64px;
	height: 64px;
}

.library-docs {
	padding: 10px;
	margin-top: 5px;
}

.library-docs .library-doc-item {
	width: 90%;
	margin: 5px auto;
	height: 32px;
	padding: 1px 2px;
	background: #ccc;
	border: solid thin #000;
	display: block;
	font-size: 1.2em;
}

.library-docs .library-doc-item img {
	width: 32px;
	height: 32px;
	cursor: move;
	vertical-align: middle;
}

ul.pagination {
    margin: 0;
    padding: 0;
    list-style: none;
}

ul.pagination li {
    display: inline-block;
}

ul.pagination li a{
    padding: 5px;
}
