{% load i18n %}
<form action="{% url "coop_cms_change_language" %}" method="post">
  <select name="language" onchange="javascript:form.submit()">
    {% for lang in LANGUAGES %}
    <option value="{{ lang.0 }}"{% ifequal LANGUAGE_CODE lang.0 %} selected="selected"{% endifequal %}>{{ lang.1 }}</option>
    {% endfor %}
  </select>
  {% if next_url_after_change_lang %}
    <input type="hidden" name="next_url_after_change_lang" value="{{ next_url_after_change_lang }}" />
  {% endif %}
</form>